/*
 * ----------------------------------------------------------------------------
 *  (C) Copyright Testing Technologies, 2001-2005.  All Rights Reserved.
 *
 *  All copies of this program, whether in whole or in part, and whether
 *  modified or not, must display this and all other embedded copyright
 *  and ownership notices in full.
 *
 *  See the file COPYRIGHT for details of redistribution and use.
 *
 *  You should have received a copy of the COPYRIGHT file along with
 *  this file; if not, write to the Testing Technologies,
 *  Rosenthaler Str. 13, 10119 Berlin, Germany.
 *
 *  TESTING TECHNOLOGIES DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
 *  SOFTWARE. IN NO EVENT SHALL TESTING TECHNOLOGIES BE LIABLE FOR ANY
 *  SPECIAL, DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 *  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 *  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 *  THIS SOFTWARE.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
 *  EITHER EXPRESSED OR IMPLIED, INCLUDING ANY KIND OF IMPLIED OR
 *  EXPRESSED WARRANTY OF NON-INFRINGEMENT OR THE IMPLIED WARRANTIES
 *  OF MECHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * -----------------------------------------------------------------------------
 *
 *  AUTHOR:      ldte
 *  DATE:        Mar 18, 2005
 *
 *  REVISION INFO:
 *    $Revision: 1.2 $ $Date: 2005/06/22 14:44:34 $
 *    $Source: /net/ttech/cvs_root/IPv6_ETSI_STF276/javasrc/com/testingtech/ttcn/tri/NetDeviceAndMAC.java,v $
 *
 * -----------------------------------------------------------------------------
 */


package com.testingtech.ttcn.tri;

import com.testingtech.util.HexViewer;




/**
 * Class to store net device and MAC address as entry in the send hashmap
 * 
 * @author dte
 *
 */
public class NetDeviceAndMAC {
	private String f_netDeviceId = null;
	private byte [] f_mac = null;
	
	/**
	 * The constructor of the class
	 * 
	 * @param netDeviceId	The net device to store
	 * @param mac			The MAC address to store
	 */
	public NetDeviceAndMAC(String netDeviceId, byte [] mac) {
		super();
		f_netDeviceId = netDeviceId;
		f_mac = mac;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return this.f_netDeviceId.hashCode() + this.f_mac.hashCode();
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object ndam) {
		return (this.f_netDeviceId.equals(((NetDeviceAndMAC)ndam).f_netDeviceId) && this.f_mac.equals(((NetDeviceAndMAC)ndam).f_mac));
	}
	
	/**
	 * @return Returns the f_netDeviceId.
	 */
	public String getNetDeviceId() {
		return f_netDeviceId;
	}

	/**
	 * @param netDeviceId The f_netDeviceId to set.
	 */
	public void setNetDeviceId(String netDeviceId) {
		f_netDeviceId = netDeviceId;
	}

	/**
	 * @return Returns the f_mac.
	 */
	public byte [] getMAC() {
		return f_mac;
	}

	/**
	 * @param mac The f_mac to set.
	 */
	public void setMAC(byte []mac) {
		f_mac = mac;
	}

	/**
	 * Returns a string in the format "netDeviceId: " + the net device, "MAC address: " and the bytes in hex representation.
	 */
    public String toString() {
    	return "netDeviceId: " + f_netDeviceId + ", MAC address: " + HexViewer.hexString(f_mac) + "\n";
    }
}
